@@ -7,6 +7,8 @@ LastEditTime: 2022.02.02 19:08
 import os
 from datetime import datetime
 
+from unified_command.version import __header_
+
 __all__ = [
     'create_common_files',
     'Entity',
@@ -27,7 +29,7 @@ class Entity(object):
         if os.path.exists(self.file):
             return
 
-        with open(self.file, 'w', encoding='utf-8') as fp:
+        with open(self.file, 'w', encoding='utf-8', newline='\n') as fp:
             fp.write(self.content)
 
 
@@ -62,7 +64,7 @@ TEMPLATE_README = Entity('README.md', '''\
 ''')
 
 # .gitignore
-TEMPLATE_GITIGNORE = Entity('.gitignore', '''\
+TEMPLATE_GITIGNORE = Entity('.gitignore', __header_ + '''
 # Others
 .sync_folder.json
 bin/
@@ -72,6 +74,7 @@ scratches/
 
 # IDE
 .idea/
+cmake-build-debug/
 .vscode/
 .vscode-test/
 .vscodeignore
@@ -107,14 +110,14 @@ logs/
 ''')
 
 # Makefile
-TEMPLATE_MAKEFILE = Entity('Makefile', '''\
+TEMPLATE_MAKEFILE = Entity('Makefile', __header_ + '''
 .PHONY: ;
 .SILENT: ;               # no need for @
 .ONESHELL: ;             # recipes execute in same shell
 .NOTPARALLEL: ;          # wait for target to finish
 .EXPORT_ALL_VARIABLES: ; # send all vars to shell
 
-.IGNORE: dep clean;            # ignore all errors, keep going
+.IGNORE: dep clean test;            # ignore all errors, keep going
 
 ifeq ($(OS), Windows_NT)
 SHELL := pwsh.exe
